clear
clc

addpath('functions')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Import the survey data

% GPA and Wage Beliefs

% Cohort 2001, Freshmen Year
cd data\surveydata\zsurveyfresh01

% Survey 1
Data_Raw = textread('FRESH101.txt');
Data_Temp = [];
n = 1;
for p = 1:size(Data_Raw,1)
    if Data_Raw(p,1) > 100000
        Data_Temp(n,:) = Data_Raw(p,:);
        n = n + 1;
    else
        Data_Temp(n - 1,2:end) = Data_Raw(p,1:(end - 1));
    end
end

Id_01_Survey = Data_Temp(:,1);       % Identifier
W_Uncon_1Y_01_1_B = Data_Temp(:,47:51); % Wage belief: Unconditional, Cohort 2001, Year 1, Beginning, 1 Year out
W_Uncon_01_1_B = Data_Temp(:,52:56); % Wage belief: Unconditional, Cohort 2001, Year 1, Beginning, Age 28
W_Uncon_38_01_1_B = Data_Temp(:,57:61); % Wage belief: Unconditional, Cohort 2001, Year 1, Beginning, Age 38

W_375_01_1_B = Data_Temp(:,67:71);   % Wage belief: 3.75, Cohort 2001, Year 1, Beginning
W_300_01_1_B = Data_Temp(:,82:86);   % Wage belief: 3.00, Cohort 2001, Year 1, Beginning
W_200_01_1_B = Data_Temp(:,97:101);  % Wage belief: 2.00, Cohort 2001, Year 1, Beginning
GPA_01_1_B = Data_Temp(:,118:123);   % GPA belief: Cohort 2001, Year 1, Beginning

% Survey 6
Data_Raw = textread('FRESH601.txt');
Data_Temp = [];
n = 1;
for p = 1:size(Data_Raw,1)
    if Data_Raw(p,1) > 100000
        Data_Temp(n,:) = Data_Raw(p,:);
        n = n + 1;
    else
        Data_Temp(n - 1,2:end) = Data_Raw(p,1:(end - 1));
    end
end

GPA_N = Data_Temp(:,159:164);       % Distribution of the noise component in semester GPAs 

cd ..

% Cohort 2000, Freshmen Year
cd('zsurveyfresh00_2010')

% Survey 1
Data_Temp = importdata('FR-1-00.txt');

Id_00_Survey = Data_Temp(:,1);       % Identifier
W_Uncon_1Y_00_1_B = Data_Temp(:,62:66); % Wage belief: Unconditional, Cohort 2000, Year 1, Beginning, 1 Year out
W_Uncon_00_1_B = Data_Temp(:,67:71); % Wage belief: Unconditional, Cohort 2000, Year 1, Beginning, Age 28
W_Uncon_38_00_1_B = Data_Temp(:,72:76); % Wage belief: Unconditional, Cohort 2000, Year 1, Beginning, Age 38

W_375_00_1_B = Data_Temp(:,87:91);   % Wage belief: 3.75, Cohort 2000, Year 1, Beginning
W_300_00_1_B = Data_Temp(:,107:111); % Wage belief: 3.00, Cohort 2000, Year 1, Beginning
W_200_00_1_B = Data_Temp(:,127:131); % Wage belief: 2.00, Cohort 2000, Year 1, Beginning
GPA_00_1_B = Data_Temp(:,150:154);   % GPA belief: Cohort 2000, Year 1, Beginning

cd ..
cd ..
cd ..
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Data Cleaning
% Wage data
W_Cell = {'W_Uncon_1Y_00_1_B', 'W_Uncon_1Y_01_1_B', 'W_Uncon_00_1_B', 'W_Uncon_01_1_B', 'W_Uncon_38_00_1_B', 'W_Uncon_38_01_1_B', 'W_375_00_1_B', 'W_375_01_1_B', 'W_300_00_1_B', 'W_300_01_1_B', 'W_200_00_1_B', 'W_200_01_1_B'};

for i = 1:length(W_Cell)
    eval(['Index_' W_Cell{i} ' = (sum(' W_Cell{i} ' == 555 | ' W_Cell{i} ' == 999 | ' W_Cell{i} ' == 888,2) > 0 | logical(1 - isordered(' W_Cell{i} ')));']) % Missing data and non-ordered quantiles
    eval(['HH_' W_Cell{i} ' = ' W_Cell{i} '(:,5);'])
    eval(['Index_' W_Cell{i} '_Trim = HH_' W_Cell{i} ' > 250;']) % Trimming above: all students with wage upper bound greater than 250k
end

% GPA data
Index_GPA_01_1_B = (sum(GPA_01_1_B == 555 | GPA_01_1_B == 999 | GPA_01_1_B == 888,2) > 0);
GPA_01_1_B = GPA_01_1_B./repmat(sum(GPA_01_1_B,2),[1,6]);

Index_GPA_00_1_B = (sum(GPA_00_1_B == 555 | GPA_00_1_B == 999 | GPA_00_1_B == 888,2) > 0);
GPA_00_1_B = GPA_00_1_B./repmat(sum(GPA_00_1_B,2),[1,5]);

% Drop the observations with missing values
Index_T_01 = Index_W_Uncon_01_1_B | Index_W_375_01_1_B | Index_W_300_01_1_B | Index_W_200_01_1_B | Index_GPA_01_1_B | Index_W_Uncon_1Y_01_1_B | Index_W_Uncon_38_01_1_B |...
             Index_W_Uncon_01_1_B_Trim | Index_W_375_01_1_B_Trim | Index_W_300_01_1_B_Trim | Index_W_200_01_1_B_Trim;

Index_T_00 = Index_W_Uncon_00_1_B | Index_W_375_00_1_B | Index_W_300_00_1_B | Index_W_200_00_1_B | Index_GPA_00_1_B | Index_W_Uncon_1Y_00_1_B | Index_W_Uncon_38_00_1_B |...
             Index_W_Uncon_00_1_B_Trim | Index_W_375_00_1_B_Trim | Index_W_300_00_1_B_Trim | Index_W_200_00_1_B_Trim;

for i = [1,3,5,7,9,11]
    eval([W_Cell{i} '(Index_T_00,:) = [];'])
end

for i = [2,4,6,8,10,12]
    eval([W_Cell{i} '(Index_T_01,:) = [];'])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Report descriptive statistics
W_Uncon_1Y_1_B = [W_Uncon_1Y_00_1_B;W_Uncon_1Y_01_1_B];
W_Uncon_1_B = [W_Uncon_00_1_B;W_Uncon_01_1_B];
W_Uncon_38_1_B = [W_Uncon_38_00_1_B;W_Uncon_38_01_1_B];
W_Con_200_1_B = [W_200_00_1_B;W_200_01_1_B];
W_Con_300_1_B = [W_300_00_1_B;W_300_01_1_B];
W_Con_375_1_B = [W_375_00_1_B;W_375_01_1_B];

Median_W_Uncon_1Y_1_B = W_Uncon_1Y_1_B(:,3);
Median_W_Uncon_1_B = W_Uncon_1_B(:,3);
Median_W_Uncon_38_1_B = W_Uncon_38_1_B(:,3);
Median_W_Con_200_1_B = W_Con_200_1_B(:,3);
Median_W_Con_300_1_B = W_Con_300_1_B(:,3);
Median_W_Con_375_1_B = W_Con_375_1_B(:,3);

iqr_W_Uncon_1Y_1_B = W_Uncon_1Y_1_B(:,4) - W_Uncon_1Y_1_B(:,2);
iqr_W_Uncon_1_B = W_Uncon_1_B(:,4) - W_Uncon_1_B(:,2);
iqr_W_Uncon_38_1_B = W_Uncon_38_1_B(:,4) - W_Uncon_38_1_B(:,2);
iqr_W_Con_200_1_B = W_Con_200_1_B(:,4) - W_Con_200_1_B(:,2);
iqr_W_Con_300_1_B = W_Con_300_1_B(:,4) - W_Con_300_1_B(:,2);
iqr_W_Con_375_1_B = W_Con_375_1_B(:,4) - W_Con_375_1_B(:,2);

Table_1 = [mean(Median_W_Uncon_1Y_1_B),mean(Median_W_Uncon_1_B),mean(Median_W_Uncon_38_1_B),mean(Median_W_Con_200_1_B),mean(Median_W_Con_300_1_B),mean(Median_W_Con_375_1_B); ...
           std(Median_W_Uncon_1Y_1_B),std(Median_W_Uncon_1_B),std(Median_W_Uncon_38_1_B),std(Median_W_Con_200_1_B),std(Median_W_Con_300_1_B),std(Median_W_Con_375_1_B); ...
           mean(iqr_W_Uncon_1Y_1_B),mean(iqr_W_Uncon_1_B),mean(iqr_W_Uncon_38_1_B),mean(iqr_W_Con_200_1_B),mean(iqr_W_Con_300_1_B),mean(iqr_W_Con_375_1_B); ...
           std(iqr_W_Uncon_1Y_1_B),std(iqr_W_Uncon_1_B),std(iqr_W_Uncon_38_1_B),std(iqr_W_Con_200_1_B),std(iqr_W_Con_300_1_B),std(iqr_W_Con_375_1_B)]
