clear
clc

addpath('functions')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Import the survey data

% GPA and Wage Beliefs

% Cohort 2001, Freshmen Year
cd data\surveydata\zsurveyfresh01

% Survey 1
Data_Raw = textread('FRESH101.txt');
Data_Temp = [];
n = 1;
for p = 1:size(Data_Raw,1)
    if Data_Raw(p,1) > 100000
        Data_Temp(n,:) = Data_Raw(p,:);
        n = n + 1;
    else
        Data_Temp(n - 1,2:end) = Data_Raw(p,1:(end - 1));
    end
end

Id_01_Survey = Data_Temp(:,1);       % Identifier
W_Uncon_01_1_B = Data_Temp(:,52:56); % Wage belief: Unconditional, Cohort 2001, Year 1, Beginning

W_375_01_1_B = Data_Temp(:,67:71);   % Wage belief: 3.75, Cohort 2001, Year 1, Beginning
W_300_01_1_B = Data_Temp(:,82:86);   % Wage belief: 3.00, Cohort 2001, Year 1, Beginning
W_200_01_1_B = Data_Temp(:,97:101);  % Wage belief: 2.00, Cohort 2001, Year 1, Beginning
GPA_01_1_B = Data_Temp(:,118:123);   % GPA belief: Cohort 2001, Year 1, Beginning

% Survey 6
Data_Raw = textread('FRESH601.txt');
Data_Temp = [];
n = 1;
for p = 1:size(Data_Raw,1)
    if Data_Raw(p,1) > 100000
        Data_Temp(n,:) = Data_Raw(p,:);
        n = n + 1;
    else
        Data_Temp(n - 1,2:end) = Data_Raw(p,1:(end - 1));
    end
end

GPA_N = Data_Temp(:,159:164);       % Distribution of the noise component in semester GPAs 

cd ..

% Cohort 2000, Freshmen Year
cd('zsurveyfresh00_2010')

% Survey 1
Data_Temp = importdata('FR-1-00.txt');

Id_00_Survey = Data_Temp(:,1);       % Identifier
W_Uncon_00_1_B = Data_Temp(:,67:71); % Wage belief: Unconditional, Cohort 2000, Year 1, Beginning

W_375_00_1_B = Data_Temp(:,87:91);   % Wage belief: 3.75, Cohort 2000, Year 1, Beginning
W_300_00_1_B = Data_Temp(:,107:111); % Wage belief: 3.00, Cohort 2000, Year 1, Beginning
W_200_00_1_B = Data_Temp(:,127:131); % Wage belief: 2.00, Cohort 2000, Year 1, Beginning
GPA_00_1_B = Data_Temp(:,150:154);   % GPA belief: Cohort 2000, Year 1, Beginning

cd ..
cd ..
cd ..
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Data Cleaning
% Wage data
W_Cell = {'W_Uncon_00_1_B', 'W_Uncon_01_1_B', 'W_375_00_1_B', 'W_375_01_1_B', 'W_300_00_1_B', 'W_300_01_1_B', 'W_200_00_1_B', 'W_200_01_1_B'};

for i = 1:length(W_Cell)
    eval(['Index_' W_Cell{i} ' = (sum(' W_Cell{i} ' == 555 | ' W_Cell{i} ' == 999 | ' W_Cell{i} ' == 888,2) > 0 | logical(1 - isordered(' W_Cell{i} ')));']) % Missing data and non-ordered quantiles
    eval(['HH_' W_Cell{i} ' = ' W_Cell{i} '(:,5);'])
    eval(['Index_' W_Cell{i} '_Trim = HH_' W_Cell{i} ' > 250;']) % Trimming above: all students with wage upper bound greater than 250k
end

% GPA data
Index_GPA_01_1_B = (sum(GPA_01_1_B == 555 | GPA_01_1_B == 999 | GPA_01_1_B == 888,2) > 0);
GPA_01_1_B = GPA_01_1_B./repmat(sum(GPA_01_1_B,2),[1,6]);

Index_GPA_00_1_B = (sum(GPA_00_1_B == 555 | GPA_00_1_B == 999 | GPA_00_1_B == 888,2) > 0);
GPA_00_1_B = GPA_00_1_B./repmat(sum(GPA_00_1_B,2),[1,5]);

% Drop the observations with missing values
Index_T_01 = Index_W_Uncon_01_1_B | Index_W_375_01_1_B | Index_W_300_01_1_B | Index_W_200_01_1_B | Index_GPA_01_1_B | ...
             Index_W_Uncon_01_1_B_Trim | Index_W_375_01_1_B_Trim | Index_W_300_01_1_B_Trim | Index_W_200_01_1_B_Trim;

Index_T_00 = Index_W_Uncon_00_1_B | Index_W_375_00_1_B | Index_W_300_00_1_B | Index_W_200_00_1_B | Index_GPA_00_1_B | ...
             Index_W_Uncon_00_1_B_Trim | Index_W_375_00_1_B_Trim | Index_W_300_00_1_B_Trim | Index_W_200_00_1_B_Trim;

for i = [1,3,5,7]
    eval([W_Cell{i} '(Index_T_00,:) = [];'])
end

for i = [2,4,6,8]
    eval([W_Cell{i} '(Index_T_01,:) = [];'])
end

GPA_00_1_B(Index_T_00,:) = [];
GPA_01_1_B(Index_T_01,:) = [];
GPA_N(Index_T_01,:) = [];

% "Luck" data
Index_GPA_N_N = (sum(GPA_N(:,1:3) == 555 | GPA_N(:,1:3) == 999 | GPA_N(:,1:3) == 888,2) > 0);
GPA_N(:,1:3) = GPA_N(:,1:3)./repmat(sum(GPA_N(:,1:3),2),[1,3]);
Index_GPA_N_P = (sum(GPA_N(:,4:6) == 555 | GPA_N(:,4:6) == 999 | GPA_N(:,4:6) == 888,2) > 0);
GPA_N(:,4:6) = GPA_N(:,4:6)./repmat(sum(GPA_N(:,4:6),2),[1,3]);
Index_GPA_N = Index_GPA_N_N & Index_GPA_N_P;

GPA_N(:,:) = [GPA_N(:,1:3).*repmat((1 - Index_GPA_N_N),[1,3]) + GPA_N(:,4:6).*repmat(Index_GPA_N_N,[1,3]), GPA_N(:,4:6).*repmat((1 - Index_GPA_N_P),[1,3]) + GPA_N(:,1:3).*repmat(Index_GPA_N_P,[1,3])];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the mean and variance of GPA distributions
% Calculate the distribution of theta and epsilon for those with epsilon data
options = optimset('Algorithm','interior-point','display','off');

GPA_N_P = GPA_N(logical(1 - Index_GPA_N),:);
GPA_01_1_B_P = GPA_01_1_B(logical(1 - Index_GPA_N),:);
ParameterG_P = zeros(size(GPA_01_1_B_P,1),3);

for i = 1:size(GPA_01_1_B_P,1)
    temp = @(x)Obj_eps(GPA_01_1_B_P(i,:),GPA_N_P(i,:),x(1),x(2),x(3));
    xT = fmincon(temp,[3,1,1],[],[],[],[],[-10,0,0],[10,10,10],[],options);
    ParameterG_P(i,:) = xT;
end

% Compute the median epsilon/theta ratio
ET_ratio = median(ParameterG_P(:,3)./ParameterG_P(:,2));

% Calculate the distribution of theta and epsilon for those without epsilon data
GPA_01_1_B_N = GPA_01_1_B(Index_GPA_N,:);
ParameterG_N = zeros(size(GPA_01_1_B_N,1),3);

for i = 1:size(GPA_01_1_B_N,1)
    temp = @(x) Obj_Neps( GPA_01_1_B_N(i,:), ET_ratio, x(1), x(2));
    xT = fmincon(temp,[3,1],[],[],[],[],[-10,0],[10,10],[],options);
    ParameterG_N(i,:) = [xT,ET_ratio*xT(2)];
end

ParameterG_N00 = zeros(size(GPA_00_1_B,1),3);

for i = 1:size(GPA_00_1_B,1)
    temp = @(x) Obj_Neps00( GPA_00_1_B(i,:), ET_ratio, x(1), x(2));
    xT = fmincon(temp,[3,1],[],[],[],[],[-10,0],[10,10],[],options);
    ParameterG_N00(i,:) = [xT,ET_ratio*xT(2)];
end

% Combine the results
ParameterG_01 = zeros(size(GPA_01_1_B,1),3);
j = 1;
k = 1;

for i = 1:size(ParameterG_01,1)
    if Index_GPA_N(i) == 1
        ParameterG_01(i,:) = ParameterG_N(j,:);
        j = j + 1;
    else
        ParameterG_01(i,:) = ParameterG_P(k,:);
        k = k + 1;
    end
end

ParameterG = [ParameterG_N00;ParameterG_01];

sigmaG_Star = sqrt(ParameterG(:,2).^2 + ParameterG(:,3).^2/8);
meanG_Star = ParameterG(:,1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Report descriptive statistics
% Direct, Stepwise Uniform
W_Uncon_SU = mean_SU([W_Uncon_00_1_B;W_Uncon_01_1_B]);
S_Uncon_SU = std_SU([W_Uncon_00_1_B;W_Uncon_01_1_B]);

mu_W_Uncon_SU = mean(W_Uncon_SU);
std_W_Uncon_SU = std(W_Uncon_SU);

mu_S_Uncon_SU = mean(S_Uncon_SU);
std_S_Uncon_SU = std(S_Uncon_SU);

Ratio_Uncon_SU = S_Uncon_SU./W_Uncon_SU;
mu_Ratio_Uncon_SU = mean(Ratio_Uncon_SU);
std_Ratio_Uncon_SU = std(Ratio_Uncon_SU);

% Direct, Log-normal
W_Uncon_LN = mean_LN([W_Uncon_00_1_B;W_Uncon_01_1_B]);
S_Uncon_LN = std_LN([W_Uncon_00_1_B;W_Uncon_01_1_B]);

mu_W_Uncon_LN = mean(W_Uncon_LN);
std_W_Uncon_LN = std(W_Uncon_LN);

mu_S_Uncon_LN = mean(S_Uncon_LN);
std_S_Uncon_LN = std(S_Uncon_LN);

Ratio_Uncon_LN = S_Uncon_LN./W_Uncon_LN;
mu_Ratio_Uncon_LN = mean(Ratio_Uncon_LN);
std_Ratio_Uncon_LN = std(Ratio_Uncon_LN);

% Direct, Normal
W_Uncon_N = mean_N([W_Uncon_00_1_B;W_Uncon_01_1_B]);
S_Uncon_N = std_N([W_Uncon_00_1_B;W_Uncon_01_1_B]);

mu_W_Uncon_N = mean(W_Uncon_N);
std_W_Uncon_N = std(W_Uncon_N);

mu_S_Uncon_N = mean(S_Uncon_N);
std_S_Uncon_N = std(S_Uncon_N);

Ratio_Uncon_N = S_Uncon_N./W_Uncon_N;
mu_Ratio_Uncon_N = mean(Ratio_Uncon_N);
std_Ratio_Uncon_N = std(Ratio_Uncon_N);

% Computed, Stepwise Uniform
W_375_SU = mean_SU([W_375_00_1_B;W_375_01_1_B]);
S_375_SU = std_SU([W_375_00_1_B;W_375_01_1_B]);
W_300_SU = mean_SU([W_300_00_1_B;W_300_01_1_B]);
S_300_SU = std_SU([W_300_00_1_B;W_300_01_1_B]);
W_200_SU = mean_SU([W_200_00_1_B;W_200_01_1_B]);
S_200_SU = std_SU([W_200_00_1_B;W_200_01_1_B]);

N = 100000;

[ M_Uncon_C_SU, S_Uncon_C_SU ] = MS_Con( [W_200_SU,W_300_SU,W_375_SU], [S_200_SU,S_300_SU,S_375_SU], ParameterG, N );

mu_M_Uncon_C_SU = mean(M_Uncon_C_SU);
std_M_Uncon_C_SU = std(M_Uncon_C_SU);

mu_S_Uncon_C_SU = mean(S_Uncon_C_SU);
std_S_Uncon_C_SU = std(S_Uncon_C_SU);

Ratio_Uncon_C_SU = S_Uncon_C_SU./M_Uncon_C_SU;
mu_Ratio_Uncon_C_SU = mean(Ratio_Uncon_C_SU);
std_Ratio_Uncon_C_SU = std(Ratio_Uncon_C_SU);

% Computed, Log-normal
W_375_LN = mean_LN([W_375_00_1_B;W_375_01_1_B]);
S_375_LN = std_LN([W_375_00_1_B;W_375_01_1_B]);
W_300_LN = mean_LN([W_300_00_1_B;W_300_01_1_B]);
S_300_LN = std_LN([W_300_00_1_B;W_300_01_1_B]);
W_200_LN = mean_LN([W_200_00_1_B;W_200_01_1_B]);
S_200_LN = std_LN([W_200_00_1_B;W_200_01_1_B]);

N = 100000;

[ M_Uncon_C_LN, S_Uncon_C_LN ] = MS_Con( [W_200_LN,W_300_LN,W_375_LN], [S_200_LN,S_300_LN,S_375_LN], ParameterG, N );

mu_M_Uncon_C_LN = mean(M_Uncon_C_LN);
std_M_Uncon_C_LN = std(M_Uncon_C_LN);

mu_S_Uncon_C_LN = mean(S_Uncon_C_LN);
std_S_Uncon_C_LN = std(S_Uncon_C_LN);

Ratio_Uncon_C_LN = S_Uncon_C_LN./M_Uncon_C_LN;
mu_Ratio_Uncon_C_LN = mean(Ratio_Uncon_C_LN);
std_Ratio_Uncon_C_LN = std(Ratio_Uncon_C_LN);

% Computed, Normal
W_375_N = mean_N([W_375_00_1_B;W_375_01_1_B]);
S_375_N = std_N([W_375_00_1_B;W_375_01_1_B]);
W_300_N = mean_N([W_300_00_1_B;W_300_01_1_B]);
S_300_N = std_N([W_300_00_1_B;W_300_01_1_B]);
W_200_N = mean_N([W_200_00_1_B;W_200_01_1_B]);
S_200_N = std_N([W_200_00_1_B;W_200_01_1_B]);

N = 100000;

[ M_Uncon_C_N, S_Uncon_C_N ] = MS_Con( [W_200_N,W_300_N,W_375_N], [S_200_N,S_300_N,S_375_N], ParameterG, N );

mu_M_Uncon_C_N = mean(M_Uncon_C_N);
std_M_Uncon_C_N = std(M_Uncon_C_N);

mu_S_Uncon_C_N = mean(S_Uncon_C_N);
std_S_Uncon_C_N = std(S_Uncon_C_N);

Ratio_Uncon_C_N = S_Uncon_C_N./M_Uncon_C_N;
mu_Ratio_Uncon_C_N = mean(Ratio_Uncon_C_N);
std_Ratio_Uncon_C_N = std(Ratio_Uncon_C_N);

Table_2 = [mu_W_Uncon_LN,mu_S_Uncon_LN,mu_Ratio_Uncon_LN;std_W_Uncon_LN,std_S_Uncon_LN,std_Ratio_Uncon_LN; ...
           mu_W_Uncon_N,mu_S_Uncon_N,mu_Ratio_Uncon_N;std_W_Uncon_N,std_S_Uncon_N,std_Ratio_Uncon_N; ...
           mu_W_Uncon_SU,mu_S_Uncon_SU,mu_Ratio_Uncon_SU;std_W_Uncon_SU,std_S_Uncon_SU,std_Ratio_Uncon_SU; ...
           mu_M_Uncon_C_LN,mu_S_Uncon_C_LN,mu_Ratio_Uncon_C_LN;std_M_Uncon_C_LN,std_S_Uncon_C_LN,std_Ratio_Uncon_C_LN; ...
           mu_M_Uncon_C_N,mu_S_Uncon_C_N,mu_Ratio_Uncon_C_N;std_M_Uncon_C_N,std_S_Uncon_C_N,std_Ratio_Uncon_C_N; ...
           mu_M_Uncon_C_SU,mu_S_Uncon_C_SU,mu_Ratio_Uncon_C_SU;std_M_Uncon_C_SU,std_S_Uncon_C_SU,std_Ratio_Uncon_C_SU]