clear
clc

addpath('functions')

% Cohort 2001, Freshmen Year
cd data\surveydata\zsurveyfresh01

% Survey 1
Data_Raw = textread('FRESH101.txt');
Data_Temp = [];
n = 1;
for p = 1:size(Data_Raw,1)
    if Data_Raw(p,1) > 100000
        Data_Temp(n,:) = Data_Raw(p,:);
        
        n = n + 1;
    else
        Data_Temp(n - 1,2:end) = Data_Raw(p,1:(end - 1));
    end
end

Id_01_Survey = Data_Temp(:,1);            % Identifier
W_Uncon_01_1_B = Data_Temp(:,52:56);      % Wage belief: Unconditional, Cohort 2001, Year 1, Beginning
Prob_Major_01_1_B = Data_Temp(:,159:166); % Major belief: Probability

cd ..

% Cohort 2000, Freshmen Year
cd('zsurveyfresh00_2010')

% Survey 1
Data_Temp = importdata('FR-1-00.txt');

Id_00_Survey = Data_Temp(:,1);            % Identifier
W_Uncon_00_1_B = Data_Temp(:,67:71);      % Wage belief: Unconditional, Cohort 2000, Year 1, Beginning
Prob_Major_00_1_B = Data_Temp(:,190:197); % Major belief: Probability

cd ..
cd ..
cd ..

% Clean data
% Income data 
Index_W_Uncon_01_1_B = sum(W_Uncon_01_1_B == 555 | W_Uncon_01_1_B == 999 | W_Uncon_01_1_B == 888 | logical(1 - isordered(W_Uncon_01_1_B)),2) > 0;
Index_W_Uncon_00_1_B = sum(W_Uncon_00_1_B == 555 | W_Uncon_00_1_B == 999 | W_Uncon_00_1_B == 888 | logical(1 - isordered(W_Uncon_00_1_B)),2) > 0;

Index_W_Uncon_01_1_B_Trim = W_Uncon_01_1_B(:,5) > 250;
Index_W_Uncon_00_1_B_Trim = W_Uncon_00_1_B(:,5) > 250;

% Major data
Index_Prob_Major_01_1_B = sum(Prob_Major_01_1_B == 555 | Prob_Major_01_1_B == 999 | Prob_Major_01_1_B == 888,2) > 0;
Index_Prob_Major_00_1_B = sum(Prob_Major_00_1_B == 555 | Prob_Major_00_1_B == 999 | Prob_Major_00_1_B == 888,2) > 0;

% Combine
Index_01 = Index_W_Uncon_01_1_B | Index_W_Uncon_01_1_B_Trim | Index_Prob_Major_01_1_B;
Index_00 = Index_W_Uncon_00_1_B | Index_W_Uncon_00_1_B_Trim | Index_Prob_Major_00_1_B;

% Drop missing observations
W_Uncon_01_1_B(Index_01,:) = [];
W_Uncon_00_1_B(Index_00,:) = [];
Prob_Major_01_1_B(Index_01,:) = [];
Prob_Major_00_1_B(Index_00,:) = [];

W_Uncon_1_B = [W_Uncon_00_1_B;W_Uncon_01_1_B];
Prob_Major_1_B = [Prob_Major_00_1_B;Prob_Major_01_1_B];
Prob_Major_1_B = Prob_Major_1_B./repmat(sum(Prob_Major_1_B,2),1,8);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute Uncertainty Measures
mean_W_Uncon_1_B_SU = mean_SU(W_Uncon_1_B);
mean_W_Uncon_1_B_LN = mean_LN(W_Uncon_1_B);
mean_W_Uncon_1_B_N = mean_N(W_Uncon_1_B);

std_W_Uncon_1_B_SU = std_SU(W_Uncon_1_B);
std_W_Uncon_1_B_LN = std_LN(W_Uncon_1_B);
std_W_Uncon_1_B_N = std_N(W_Uncon_1_B);

% Load regressors
cd processed_data
load regressor

cd ..

% Drop missing observations
Male_00(Index_00,:) = [];
Male_01(Index_01,:) = [];
Male = [Male_00;Male_01];

Black_00(Index_00,:) = [];
Black_01(Index_01,:) = [];
Black = [Black_00;Black_01];

CACT_00(Index_00,:) = [];
CACT_01(Index_01,:) = [];
CACT = [CACT_00;CACT_01];

% Data Clearning
Index_Male = Male ~= 0 & Male ~= 1;
Index_Black = Black ~= 0 & Black ~= 1;
Index_CACT = CACT > 36;

Index_F = Index_Male | Index_Black | Index_CACT;

% Drop missing observations
Male(Index_F,:) = [];
Black(Index_F,:) = [];
CACT(Index_F,:) = [];
Regs = [ones(size(Male,1),1),Male,Black,CACT];

Prob_Major_1_B(Index_F,:) = [];
Prob_Major_1_B(:,1) = Prob_Major_1_B(:,1) + Prob_Major_1_B(:,6);
Prob_Major_1_B(:,6) = [];

mean_W_Uncon_1_B_SU(Index_F,:) = [];
mean_W_Uncon_1_B_LN(Index_F,:) = [];
mean_W_Uncon_1_B_N(Index_F,:) = [];

std_W_Uncon_1_B_SU(Index_F,:) = [];
std_W_Uncon_1_B_LN(Index_F,:) = [];
std_W_Uncon_1_B_N(Index_F,:) = [];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Index_temp_W = mean_W_Uncon_1_B_SU < prctile(mean_W_Uncon_1_B_SU,95) & std_W_Uncon_1_B_SU < prctile(std_W_Uncon_1_B_SU,95);
[ beta_major_SU, std_major_SU, CI_major_SU, beta_var_SU ] = Estimation_Major_Bootstrap( mean_W_Uncon_1_B_SU(Index_temp_W,:), std_W_Uncon_1_B_SU(Index_temp_W,:).^2, Prob_Major_1_B(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );
p_value_SU = p_value_Major_Bootstrap( mean_W_Uncon_1_B_SU(Index_temp_W,:), std_W_Uncon_1_B_SU(Index_temp_W,:).^2, Prob_Major_1_B(Index_temp_W,:), Regs(Index_temp_W,:), 10000 );

Index_temp_W = mean_W_Uncon_1_B_LN < prctile(mean_W_Uncon_1_B_LN,95) & std_W_Uncon_1_B_LN < prctile(std_W_Uncon_1_B_LN,95);
[ beta_major_LN, std_major_LN, CI_major_LN, beta_var_LN ] = Estimation_Major_Bootstrap( mean_W_Uncon_1_B_LN(Index_temp_W,:), std_W_Uncon_1_B_LN(Index_temp_W,:).^2, Prob_Major_1_B(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );
p_value_LN = p_value_Major_Bootstrap( mean_W_Uncon_1_B_LN(Index_temp_W,:), std_W_Uncon_1_B_LN(Index_temp_W,:).^2, Prob_Major_1_B(Index_temp_W,:), Regs(Index_temp_W,:), 10000 );

Index_temp_W = mean_W_Uncon_1_B_N < prctile(mean_W_Uncon_1_B_N,95) & std_W_Uncon_1_B_N < prctile(std_W_Uncon_1_B_N,95);
[ beta_major_N, std_major_N, CI_major_N, beta_var_N ] = Estimation_Major_Bootstrap( mean_W_Uncon_1_B_N(Index_temp_W,:), std_W_Uncon_1_B_N(Index_temp_W,:).^2, Prob_Major_1_B(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );
p_value_N = p_value_Major_Bootstrap( mean_W_Uncon_1_B_N(Index_temp_W,:), std_W_Uncon_1_B_N(Index_temp_W,:).^2, Prob_Major_1_B(Index_temp_W,:), Regs(Index_temp_W,:), 10000 );

% Compute the first term on the RHS
RHS_1_SU = std_major(repmat([beta_major_SU(1:6),0],[size(Prob_Major_1_B,1),1]),Prob_Major_1_B).^2;
RHS_1_LN = std_major(repmat([beta_major_LN(1:6),0],[size(Prob_Major_1_B,1),1]),Prob_Major_1_B).^2;
RHS_1_N = std_major(repmat([beta_major_N(1:6),0],[size(Prob_Major_1_B,1),1]),Prob_Major_1_B).^2;

% Compute the predicted second term on the RHS
RHS_2_SU_P = [Prob_Major_1_B(:,1:6),Regs]*beta_var_SU;
RHS_2_LN_P = [Prob_Major_1_B(:,1:6),Regs]*beta_var_LN;
RHS_2_N_P = [Prob_Major_1_B(:,1:6),Regs]*beta_var_N;

% Compute the ratio
Ratio_SU = RHS_1_SU./(RHS_2_SU_P + RHS_1_SU);
Ratio_LN = RHS_1_LN./(RHS_2_LN_P + RHS_1_LN);
Ratio_N = RHS_1_N./(RHS_2_N_P + RHS_1_N);

Table_6 = [mean(Ratio_SU),prctile(Ratio_SU,25),prctile(Ratio_SU,50),prctile(Ratio_SU,75);mean(Ratio_LN),prctile(Ratio_LN,25),prctile(Ratio_LN,50),prctile(Ratio_LN,75);mean(Ratio_N),prctile(Ratio_N,25),prctile(Ratio_N,50),prctile(Ratio_N,75)]

% Report the estimates
[temp, sort_beta_major_M_SU] = sort(-[beta_major_SU(1:6),0]);
[temp, sort_beta_major_M_SU] = sort(sort_beta_major_M_SU);
[temp, sort_beta_major_M_LN] = sort(-[beta_major_LN(1:6),0]);
[temp, sort_beta_major_M_LN] = sort(sort_beta_major_M_LN);
[temp, sort_beta_major_M_N] = sort(-[beta_major_N(1:6),0]);
[temp, sort_beta_major_M_N] = sort(sort_beta_major_M_N);
[temp, sort_beta_major_var_SU] = sort(-[beta_major_SU(7:end),0]);
[temp, sort_beta_major_var_SU] = sort(sort_beta_major_var_SU);
[temp, sort_beta_major_var_LN] = sort(-[beta_major_LN(7:end),0]);
[temp, sort_beta_major_var_LN] = sort(sort_beta_major_var_LN);
[temp, sort_beta_major_var_N] = sort(-[beta_major_N(7:end),0]);
[temp, sort_beta_major_var_N] = sort(sort_beta_major_var_N);

Table_7 = [beta_major_SU(1:6),0;p_value_SU(1:6)',0;sort_beta_major_M_SU; ...
         beta_major_LN(1:6),0;p_value_LN(1:6)',0;sort_beta_major_M_LN; ...
         beta_major_N(1:6),0;p_value_N(1:6)',0;sort_beta_major_M_N; ...
         beta_major_SU(7:end),0;p_value_SU(7:end)',0;sort_beta_major_var_SU; ...
         beta_major_LN(7:end),0;p_value_LN(7:end)',0;sort_beta_major_var_LN; ...
         beta_major_N(7:end),0;p_value_N(7:end)',0;sort_beta_major_var_N]
     
