clear
clc

addpath('functions')

% We decompose total initial income uncertainty into contributions of GPA,
% major and other factors

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Import the survey data

% GPA and Wage Beliefs

% Cohort 2001, Freshmen Year
cd data\surveydata\zsurveyfresh01

% Survey 1
Data_Raw = textread('FRESH101.txt');
Data_Temp = [];
n = 1;
for p = 1:size(Data_Raw,1)
    if Data_Raw(p,1) > 100000
        Data_Temp(n,:) = Data_Raw(p,:);
        n = n + 1;
    else
        Data_Temp(n - 1,2:end) = Data_Raw(p,1:(end - 1));
    end
end

Id_01_Survey = Data_Temp(:,1);       % Identifier
W_Uncon_01_1_B = Data_Temp(:,52:56); % Wage belief: Unconditional, Cohort 2001, Year 1, Beginning

W_375_01_1_B = Data_Temp(:,67:71);   % Wage belief: 3.75, Cohort 2001, Year 1, Beginning
W_300_01_1_B = Data_Temp(:,82:86);   % Wage belief: 3.00, Cohort 2001, Year 1, Beginning
W_200_01_1_B = Data_Temp(:,97:101);  % Wage belief: 2.00, Cohort 2001, Year 1, Beginning
GPA_01_1_B = Data_Temp(:,118:123);   % GPA belief: Cohort 2001, Year 1, Beginning
Prob_Major_01_1_B = Data_Temp(:,159:166); % Major belief: Probability
GPA_Major_01_1_B = Data_Temp(:,167:174);  % Major belief: Average GPA

% Survey 6
Data_Raw = textread('FRESH601.txt');
Data_Temp = [];          
n = 1;
for p = 1:size(Data_Raw,1)
    if Data_Raw(p,1) > 100000
        Data_Temp(n,:) = Data_Raw(p,:);
        n = n + 1;
    else
        Data_Temp(n - 1,2:end) = Data_Raw(p,1:(end - 1));
    end
end

GPA_N = Data_Temp(:,159:164);       % Distribution of the noise component in semester GPAs 

cd ..

% Cohort 2000, Freshmen Year
cd('zsurveyfresh00_2010')

% Survey 1
Data_Temp = importdata('FR-1-00.txt');

Id_00_Survey = Data_Temp(:,1);       % Identifier
W_Uncon_00_1_B = Data_Temp(:,67:71); % Wage belief: Unconditional, Cohort 2000, Year 1, Beginning

W_375_00_1_B = Data_Temp(:,87:91);   % Wage belief: 3.75, Cohort 2000, Year 1, Beginning
W_300_00_1_B = Data_Temp(:,107:111); % Wage belief: 3.00, Cohort 2000, Year 1, Beginning
W_200_00_1_B = Data_Temp(:,127:131); % Wage belief: 2.00, Cohort 2000, Year 1, Beginning
GPA_00_1_B = Data_Temp(:,150:154);   % GPA belief: Cohort 2000, Year 1, Beginning
Prob_Major_00_1_B = Data_Temp(:,190:197); % Major belief: Probability
GPA_Major_00_1_B = Data_Temp(:,198:205); % Major belief: Average GPA

cd ..
cd ..
cd ..
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Data Cleaning
% Wage data
W_Cell = {'W_Uncon_00_1_B', 'W_Uncon_01_1_B', 'W_375_00_1_B', 'W_375_01_1_B', 'W_300_00_1_B', 'W_300_01_1_B', 'W_200_00_1_B', 'W_200_01_1_B'};

for i = 1:length(W_Cell)
    eval(['Index_' W_Cell{i} ' = (sum(' W_Cell{i} ' == 555 | ' W_Cell{i} ' == 999 | ' W_Cell{i} ' == 888,2) > 0 | logical(1 - isordered(' W_Cell{i} ')));']) % Missing data and non-ordered quantiles
    eval(['HH_' W_Cell{i} ' = ' W_Cell{i} '(:,5);'])
    eval(['Index_' W_Cell{i} '_Trim = HH_' W_Cell{i} ' > 250;']) % Trimming above: all students with wage upper bound greater than 250k
end

% GPA data
Index_GPA_01_1_B = (sum(GPA_01_1_B == 555 | GPA_01_1_B == 999 | GPA_01_1_B == 888,2) > 0);
GPA_01_1_B = GPA_01_1_B./repmat(sum(GPA_01_1_B,2),[1,6]);

Index_GPA_00_1_B = (sum(GPA_00_1_B == 555 | GPA_00_1_B == 999 | GPA_00_1_B == 888,2) > 0);
GPA_00_1_B = GPA_00_1_B./repmat(sum(GPA_00_1_B,2),[1,5]);

% Major data
Index_Prob_Major_01_1_B = sum(Prob_Major_01_1_B == 555 | Prob_Major_01_1_B == 999 | Prob_Major_01_1_B == 888,2) > 0;
Index_Prob_Major_00_1_B = sum(Prob_Major_00_1_B == 555 | Prob_Major_00_1_B == 999 | Prob_Major_00_1_B == 888,2) > 0;
Index_GPA_Major_01_1_B = sum(GPA_Major_01_1_B == 555 | GPA_Major_01_1_B == 999 | GPA_Major_01_1_B == 888,2) > 0;
Index_GPA_Major_00_1_B = sum(GPA_Major_00_1_B == 555 | GPA_Major_00_1_B == 999 | GPA_Major_00_1_B == 888,2) > 0;

% Drop the observations with missing values
Index_T_01 = Index_W_Uncon_01_1_B | Index_W_375_01_1_B | Index_W_300_01_1_B | Index_W_200_01_1_B | Index_GPA_01_1_B | ...
             Index_W_Uncon_01_1_B_Trim | Index_W_375_01_1_B_Trim | Index_W_300_01_1_B_Trim | Index_W_200_01_1_B_Trim | Index_Prob_Major_01_1_B | Index_GPA_Major_01_1_B;

Index_T_00 = Index_W_Uncon_00_1_B | Index_W_375_00_1_B | Index_W_300_00_1_B | Index_W_200_00_1_B | Index_GPA_00_1_B | ...
             Index_W_Uncon_00_1_B_Trim | Index_W_375_00_1_B_Trim | Index_W_300_00_1_B_Trim | Index_W_200_00_1_B_Trim | Index_Prob_Major_00_1_B | Index_GPA_Major_00_1_B;

GPA_00_1_B(Index_T_00,:) = [];
GPA_01_1_B(Index_T_01,:) = [];
GPA_N(Index_T_01,:) = [];

% "Luck" data
Index_GPA_N_N = (sum(GPA_N(:,1:3) == 555 | GPA_N(:,1:3) == 999 | GPA_N(:,1:3) == 888,2) > 0);
GPA_N(:,1:3) = GPA_N(:,1:3)./repmat(sum(GPA_N(:,1:3),2),[1,3]);
Index_GPA_N_P = (sum(GPA_N(:,4:6) == 555 | GPA_N(:,4:6) == 999 | GPA_N(:,4:6) == 888,2) > 0);
GPA_N(:,4:6) = GPA_N(:,4:6)./repmat(sum(GPA_N(:,4:6),2),[1,3]);
Index_GPA_N = Index_GPA_N_N & Index_GPA_N_P;

GPA_N(:,:) = [GPA_N(:,1:3).*repmat((1 - Index_GPA_N_N),[1,3]) + GPA_N(:,4:6).*repmat(Index_GPA_N_N,[1,3]), GPA_N(:,4:6).*repmat((1 - Index_GPA_N_P),[1,3]) + GPA_N(:,1:3).*repmat(Index_GPA_N_P,[1,3])];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the mean and variance of GPA distributions
% Calculate the distribution of theta and epsilon for those with epsilon data
options = optimset('Algorithm','interior-point','Display','off');

GPA_N_P = GPA_N(logical(1 - Index_GPA_N),:);
GPA_01_1_B_P = GPA_01_1_B(logical(1 - Index_GPA_N),:);
ParameterG_P = zeros(size(GPA_01_1_B_P,1),3);

for i = 1:size(GPA_01_1_B_P,1)
    temp = @(x)Obj_eps(GPA_01_1_B_P(i,:),GPA_N_P(i,:),x(1),x(2),x(3));
    xT = fmincon(temp,[3,1,1],[],[],[],[],[-10,0,0],[10,10,10],[],options);
    ParameterG_P(i,:) = xT;
end
  
% Compute the median epsilon/theta ratio
ET_ratio = median(ParameterG_P(:,3)./ParameterG_P(:,2));

% Calculate the distribution of theta and epsilon for those without epsilon data
GPA_01_1_B_N = GPA_01_1_B(Index_GPA_N,:);
ParameterG_N = zeros(size(GPA_01_1_B_N,1),3);

for i = 1:size(GPA_01_1_B_N,1)
    temp = @(x) Obj_Neps( GPA_01_1_B_N(i,:), ET_ratio, x(1), x(2));
    xT = fmincon(temp,[3,1],[],[],[],[],[-10,0],[10,10],[],options);
    ParameterG_N(i,:) = [xT,ET_ratio*xT(2)];
end

ParameterG_N00 = zeros(size(GPA_00_1_B,1),3);

for i = 1:size(GPA_00_1_B,1)
    temp = @(x) Obj_Neps00( GPA_00_1_B(i,:), ET_ratio, x(1), x(2));
    xT = fmincon(temp,[3,1],[],[],[],[],[-10,0],[10,10],[],options);
    ParameterG_N00(i,:) = [xT,ET_ratio*xT(2)];
end

% Combine the results
ParameterG_01 = zeros(size(GPA_01_1_B,1),3);
j = 1;
k = 1;

for i = 1:size(ParameterG_01,1)
    if Index_GPA_N(i) == 1
        ParameterG_01(i,:) = ParameterG_N(j,:);
        j = j + 1;
    else
        ParameterG_01(i,:) = ParameterG_P(k,:);
        k = k + 1;
    end
end

ParameterG = [ParameterG_N00;ParameterG_01];

% Other data
for i = [1,3,5,7]
    eval([W_Cell{i} '(Index_T_00,:) = [];'])
end

for i = [2,4,6,8]
    eval([W_Cell{i} '(Index_T_01,:) = [];'])
end

Prob_Major_01_1_B(Index_T_01,:) = [];
Prob_Major_00_1_B(Index_T_00,:) = [];
GPA_Major_01_1_B(Index_T_01,:) = [];
GPA_Major_00_1_B(Index_T_00,:) = [];

W_Uncon_1_B = [W_Uncon_00_1_B;W_Uncon_01_1_B];
W_200_1_B = [W_200_00_1_B;W_200_01_1_B];
W_300_1_B = [W_300_00_1_B;W_300_01_1_B];
W_375_1_B = [W_375_00_1_B;W_375_01_1_B];
Prob_Major_1_B = [Prob_Major_00_1_B;Prob_Major_01_1_B];
Prob_Major_1_B(Prob_Major_1_B <= 0) = 0.01;
Prob_Major_1_B(Prob_Major_1_B >= 1) = 0.99;
Prob_Major_1_B = Prob_Major_1_B./repmat(sum(Prob_Major_1_B,2),1,8);
Prob_Major_1_B(:,1) = Prob_Major_1_B(:,1) + Prob_Major_1_B(:,6);
GPA_Major_1_B = [GPA_Major_00_1_B;GPA_Major_01_1_B];
GPA_Major_1_B(:,1) = (GPA_Major_1_B(:,1).*Prob_Major_1_B(:,1) + GPA_Major_1_B(:,6).*Prob_Major_1_B(:,6))./(Prob_Major_1_B(:,1) + Prob_Major_1_B(:,6));
GPA_Major_1_B(GPA_Major_1_B <= 2) = 2.01;
GPA_Major_1_B(GPA_Major_1_B >= 4) = 3.99;

Prob_Major_1_B(:,6) = [];
GPA_Major_1_B(:,6) = [];

% Estimate the probability of majors given GPA = 2.00, 3.00 and 3.75
rho_F = zeros(size(Prob_Major_1_B,1),12);
Prob_Major_200 = zeros(size(Prob_Major_1_B,1),7);
Prob_Major_300 = zeros(size(Prob_Major_1_B,1),7);
Prob_Major_375 = zeros(size(Prob_Major_1_B,1),7);
options_search = optimset('MaxFunEvals',100000,'MaxIter',100000);

for ind = 1:size(Prob_Major_1_B,1)
    ind
    myfun = @(rho) obj_P_M(rho,ParameterG(ind,:),Prob_Major_1_B(ind,:)',GPA_Major_1_B(ind,:),10000);
    rho_temp = fminsearch(myfun,zeros(12,1),options_search);
    rho_F(ind,:) = rho_temp';

    temp_M_200 = [rho_temp(1:6);0] + [rho_temp(7:end);0]*2;
    temp_M_200 = exp(temp_M_200 - max(temp_M_200,[],1))';
    Prob_Major_200(ind,:) = temp_M_200./repmat(sum(temp_M_200,2),[1,7]);
    
    temp_M_300 = [rho_temp(1:6);0] + [rho_temp(7:end);0]*3;
    temp_M_300 = exp(temp_M_300 - max(temp_M_300,[],1))';
    Prob_Major_300(ind,:) = temp_M_300./repmat(sum(temp_M_300,2),[1,7]);    

    temp_M_375 = [rho_temp(1:6);0] + [rho_temp(7:end);0]*3.75;
    temp_M_375 = exp(temp_M_375 - max(temp_M_375,[],1))';
    Prob_Major_375(ind,:) = temp_M_375./repmat(sum(temp_M_375,2),[1,7]);
end

cd processed_data
save conditional_prob_major rho_F Prob_Major_200 Prob_Major_300 Prob_Major_375
cd ..

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute Uncertainty Measures
mean_W_200_1_B_SU = mean_SU(W_200_1_B);
mean_W_200_1_B_LN = mean_LN(W_200_1_B);
mean_W_200_1_B_N = mean_N(W_200_1_B);

std_W_200_1_B_SU = std_SU(W_200_1_B);
std_W_200_1_B_LN = std_LN(W_200_1_B);
std_W_200_1_B_N = std_N(W_200_1_B);

mean_W_300_1_B_SU = mean_SU(W_300_1_B);
mean_W_300_1_B_LN = mean_LN(W_300_1_B);
mean_W_300_1_B_N = mean_N(W_300_1_B);

std_W_300_1_B_SU = std_SU(W_300_1_B);
std_W_300_1_B_LN = std_LN(W_300_1_B);
std_W_300_1_B_N = std_N(W_300_1_B);

mean_W_375_1_B_SU = mean_SU(W_375_1_B);
mean_W_375_1_B_LN = mean_LN(W_375_1_B);
mean_W_375_1_B_N = mean_N(W_375_1_B);

std_W_375_1_B_SU = std_SU(W_375_1_B);
std_W_375_1_B_LN = std_LN(W_375_1_B);
std_W_375_1_B_N = std_N(W_375_1_B);

% Load regressors
cd processed_data
load regressor

cd ..

% Drop missing observations
Male_00(Index_T_00,:) = [];
Male_01(Index_T_01,:) = [];
Male = [Male_00;Male_01];

Black_00(Index_T_00,:) = [];
Black_01(Index_T_01,:) = [];
Black = [Black_00;Black_01];

CACT_00(Index_T_00,:) = [];
CACT_01(Index_T_01,:) = [];
CACT = [CACT_00;CACT_01];

% Data Clearning
Index_Male = Male ~= 0 & Male ~= 1;
Index_Black = Black ~= 0 & Black ~= 1;
Index_CACT = CACT > 36;

Index_F = Index_Male | Index_Black | Index_CACT;

% Drop missing observations
Male(Index_F,:) = [];
Black(Index_F,:) = [];
CACT(Index_F,:) = [];
Regs = [ones(size(Male,1),1),Male,Black,CACT];

Prob_Major_200(Index_F,:) = [];
Prob_Major_300(Index_F,:) = [];
Prob_Major_375(Index_F,:) = [];

mean_W_200_1_B_SU(Index_F,:) = [];
mean_W_200_1_B_LN(Index_F,:) = [];
mean_W_200_1_B_N(Index_F,:) = [];

std_W_200_1_B_SU(Index_F,:) = [];
std_W_200_1_B_LN(Index_F,:) = [];
std_W_200_1_B_N(Index_F,:) = [];

mean_W_300_1_B_SU(Index_F,:) = [];
mean_W_300_1_B_LN(Index_F,:) = [];
mean_W_300_1_B_N(Index_F,:) = [];

std_W_300_1_B_SU(Index_F,:) = [];
std_W_300_1_B_LN(Index_F,:) = [];
std_W_300_1_B_N(Index_F,:) = [];

mean_W_375_1_B_SU(Index_F,:) = [];
mean_W_375_1_B_LN(Index_F,:) = [];
mean_W_375_1_B_N(Index_F,:) = [];

std_W_375_1_B_SU(Index_F,:) = [];
std_W_375_1_B_LN(Index_F,:) = [];
std_W_375_1_B_N(Index_F,:) = [];

ParameterG(Index_F,:) = [];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the first term on the RHS
% Decompose total uncertainty
% Stepwise Uniform
N = 100000;

[ temp_1, RHS_1_SU, temp_2 ] = UN_Decomp( [mean_W_200_1_B_SU,mean_W_300_1_B_SU,mean_W_375_1_B_SU], [mean_W_200_1_B_SU,mean_W_300_1_B_SU,mean_W_375_1_B_SU], ParameterG, N );

% Log-normal
[ temp_1, RHS_1_LN, temp_2 ] = UN_Decomp( [mean_W_200_1_B_LN,mean_W_300_1_B_LN,mean_W_375_1_B_LN], [mean_W_200_1_B_LN,mean_W_300_1_B_LN,mean_W_375_1_B_LN], ParameterG, N );

% Normal
[ temp_1, RHS_1_N, temp_2 ] = UN_Decomp( [mean_W_200_1_B_N,mean_W_300_1_B_N,mean_W_375_1_B_N], [mean_W_200_1_B_N,mean_W_300_1_B_N,mean_W_375_1_B_N], ParameterG, N );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Estimate the conditional mean and variance for G = 2.00, 3.00, 3.75
% GPA = 2.00
Index_temp_W = mean_W_200_1_B_SU < prctile(mean_W_200_1_B_SU,95) & std_W_200_1_B_SU < prctile(std_W_200_1_B_SU,95);
[ beta_major_200_SU, std_major_200_SU, CI_major_200_SU, beta_var_200_SU ] = Estimation_Major_Bootstrap( mean_W_200_1_B_SU(Index_temp_W,:), std_W_200_1_B_SU(Index_temp_W,:).^2, Prob_Major_200(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

Index_temp_W = mean_W_200_1_B_LN < prctile(mean_W_200_1_B_LN,95) & std_W_200_1_B_LN < prctile(std_W_200_1_B_LN,95);
[ beta_major_200_LN, std_major_200_LN, CI_major_200_LN, beta_var_200_LN ] = Estimation_Major_Bootstrap( mean_W_200_1_B_LN(Index_temp_W,:), std_W_200_1_B_LN(Index_temp_W,:).^2, Prob_Major_200(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

Index_temp_W = mean_W_200_1_B_N < prctile(mean_W_200_1_B_N,95) & std_W_200_1_B_N < prctile(std_W_200_1_B_N,95);
[ beta_major_200_N, std_major_200_N, CI_major_200_N, beta_var_200_N ] = Estimation_Major_Bootstrap( mean_W_200_1_B_N(Index_temp_W,:), std_W_200_1_B_N(Index_temp_W,:).^2, Prob_Major_200(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

% Compute the second term on the RHS
RHS_2_200_SU = std_major(repmat([beta_major_200_SU(1:6),0],[size(Prob_Major_200,1),1]),Prob_Major_200).^2;
RHS_2_200_LN = std_major(repmat([beta_major_200_LN(1:6),0],[size(Prob_Major_200,1),1]),Prob_Major_200).^2;
RHS_2_200_N = std_major(repmat([beta_major_200_N(1:6),0],[size(Prob_Major_200,1),1]),Prob_Major_200).^2;

% Compute the predicted third term on the RHS
RHS_3_200_SU_P = [Prob_Major_200(:,1:6),Regs]*beta_var_200_SU;
RHS_3_200_LN_P = [Prob_Major_200(:,1:6),Regs]*beta_var_200_LN;
RHS_3_200_N_P = [Prob_Major_200(:,1:6),Regs]*beta_var_200_N;

% GPA = 3.00
Index_temp_W = mean_W_300_1_B_SU < prctile(mean_W_300_1_B_SU,95) & std_W_300_1_B_SU < prctile(std_W_300_1_B_SU,95);
[ beta_major_300_SU, std_major_300_SU, CI_major_300_SU, beta_var_300_SU ] = Estimation_Major_Bootstrap( mean_W_300_1_B_SU(Index_temp_W,:), std_W_300_1_B_SU(Index_temp_W,:).^2, Prob_Major_300(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

Index_temp_W = mean_W_300_1_B_LN < prctile(mean_W_300_1_B_LN,95) & std_W_300_1_B_LN < prctile(std_W_300_1_B_LN,95);
[ beta_major_300_LN, std_major_300_LN, CI_major_300_LN, beta_var_300_LN ] = Estimation_Major_Bootstrap( mean_W_300_1_B_LN(Index_temp_W,:), std_W_300_1_B_LN(Index_temp_W,:).^2, Prob_Major_300(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

Index_temp_W = mean_W_300_1_B_N < prctile(mean_W_300_1_B_N,95) & std_W_300_1_B_N < prctile(std_W_300_1_B_N,95);
[ beta_major_300_N, std_major_300_N, CI_major_300_N, beta_var_300_N ] = Estimation_Major_Bootstrap( mean_W_300_1_B_N(Index_temp_W,:), std_W_300_1_B_N(Index_temp_W,:).^2, Prob_Major_300(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

% Compute the second term on the RHS
RHS_2_300_SU = std_major(repmat([beta_major_300_SU(1:6),0],[size(Prob_Major_300,1),1]),Prob_Major_300).^2;
RHS_2_300_LN = std_major(repmat([beta_major_300_LN(1:6),0],[size(Prob_Major_300,1),1]),Prob_Major_300).^2;
RHS_2_300_N = std_major(repmat([beta_major_300_N(1:6),0],[size(Prob_Major_300,1),1]),Prob_Major_300).^2;

% Compute the predicted third term on the RHS
RHS_3_300_SU_P = [Prob_Major_300(:,1:6),Regs]*beta_var_300_SU;
RHS_3_300_LN_P = [Prob_Major_300(:,1:6),Regs]*beta_var_300_LN;
RHS_3_300_N_P = [Prob_Major_300(:,1:6),Regs]*beta_var_300_N;

% GPA = 3.75
Index_temp_W = mean_W_375_1_B_SU < prctile(mean_W_375_1_B_SU,95) & std_W_375_1_B_SU < prctile(std_W_375_1_B_SU,95);
[ beta_major_375_SU, std_major_375_SU, CI_major_375_SU, beta_var_375_SU ] = Estimation_Major_Bootstrap( mean_W_375_1_B_SU(Index_temp_W,:), std_W_375_1_B_SU(Index_temp_W,:).^2, Prob_Major_375(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

Index_temp_W = mean_W_375_1_B_LN < prctile(mean_W_375_1_B_LN,95) & std_W_375_1_B_LN < prctile(std_W_375_1_B_LN,95);
[ beta_major_375_LN, std_major_375_LN, CI_major_375_LN, beta_var_375_LN ] = Estimation_Major_Bootstrap( mean_W_375_1_B_LN(Index_temp_W,:), std_W_375_1_B_LN(Index_temp_W,:).^2, Prob_Major_375(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

Index_temp_W = mean_W_375_1_B_N < prctile(mean_W_375_1_B_N,95) & std_W_375_1_B_N < prctile(std_W_375_1_B_N,95);
[ beta_major_375_N, std_major_375_N, CI_major_375_N, beta_var_375_N ] = Estimation_Major_Bootstrap( mean_W_375_1_B_N(Index_temp_W,:), std_W_375_1_B_N(Index_temp_W,:).^2, Prob_Major_375(Index_temp_W,:), Regs(Index_temp_W,:), 5, 10000 );

% Compute the second term on the RHS
RHS_2_375_SU = std_major(repmat([beta_major_375_SU(1:6),0],[size(Prob_Major_375,1),1]),Prob_Major_375).^2;
RHS_2_375_LN = std_major(repmat([beta_major_375_LN(1:6),0],[size(Prob_Major_375,1),1]),Prob_Major_375).^2;
RHS_2_375_N = std_major(repmat([beta_major_375_N(1:6),0],[size(Prob_Major_375,1),1]),Prob_Major_375).^2;

% Compute the predicted third term on the RHS
RHS_3_375_SU_P = [Prob_Major_375(:,1:6),Regs]*beta_var_375_SU;
RHS_3_375_LN_P = [Prob_Major_375(:,1:6),Regs]*beta_var_375_LN;
RHS_3_375_N_P = [Prob_Major_375(:,1:6),Regs]*beta_var_375_N;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the second and third terms on the RHS using interpolation
RHS_2_SU = zeros(size(RHS_2_200_SU,1),1);
RHS_2_LN = zeros(size(RHS_2_200_SU,1),1);
RHS_2_N = zeros(size(RHS_2_200_SU,1),1);

RHS_3_SU = zeros(size(RHS_2_200_SU,1),1);
RHS_3_LN = zeros(size(RHS_2_200_SU,1),1);
RHS_3_N = zeros(size(RHS_2_200_SU,1),1);

for ind = 1:size(RHS_2_200_SU)
    temp_G_it = rnd_G(ParameterG(ind,:),100000,1); % Randomly generate large number of realizations of G_{it}
    RHS_2_SU(ind,:) = mean(interp1([2,3,3.75],[RHS_2_200_SU(ind,:),RHS_2_300_SU(ind,:),RHS_2_375_SU(ind,:)],temp_G_it,'linear','extrap'));
    RHS_2_LN(ind,:) = mean(interp1([2,3,3.75],[RHS_2_200_LN(ind,:),RHS_2_300_LN(ind,:),RHS_2_375_LN(ind,:)],temp_G_it,'linear','extrap'));
    RHS_2_N(ind,:) = mean(interp1([2,3,3.75],[RHS_2_200_N(ind,:),RHS_2_300_N(ind,:),RHS_2_375_N(ind,:)],temp_G_it,'linear','extrap'));
    RHS_3_SU(ind,:) = mean(interp1([2,3,3.75],[RHS_3_200_SU_P(ind,:),RHS_3_300_SU_P(ind,:),RHS_3_375_SU_P(ind,:)],temp_G_it,'linear','extrap'));
    RHS_3_LN(ind,:) = mean(interp1([2,3,3.75],[RHS_3_200_LN_P(ind,:),RHS_3_300_LN_P(ind,:),RHS_3_375_LN_P(ind,:)],temp_G_it,'linear','extrap'));
    RHS_3_N(ind,:) = mean(interp1([2,3,3.75],[RHS_3_200_N_P(ind,:),RHS_3_300_N_P(ind,:),RHS_3_375_N_P(ind,:)],temp_G_it,'linear','extrap'));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the ratios
RHS_Total_SU = RHS_1_SU + RHS_2_SU + RHS_3_SU;
RHS_Total_LN = RHS_1_LN + RHS_2_LN + RHS_3_LN;
RHS_Total_N = RHS_1_N + RHS_2_N + RHS_3_N;

Ratio_12_SU = (RHS_1_SU + RHS_2_SU)./RHS_Total_SU;
Ratio_12_LN = (RHS_1_LN + RHS_2_LN)./RHS_Total_LN;
Ratio_12_N = (RHS_1_N + RHS_2_N)./RHS_Total_N;

Table_9 = [mean(Ratio_12_SU), prctile( Ratio_12_SU , 25 ), prctile( Ratio_12_SU , 50 ), prctile( Ratio_12_SU , 75 );
                 mean(Ratio_12_LN), prctile( Ratio_12_LN , 25 ), prctile( Ratio_12_LN , 50 ), prctile( Ratio_12_LN , 75 );
                 mean(Ratio_12_N), prctile( Ratio_12_N , 25 ), prctile( Ratio_12_N , 50 ), prctile( Ratio_12_N , 75 )]




