function [ Ratio, V_Uncon_G, V_Uncon_O ] = UN_Decomp( W, S, G, N )
% This function takes conditional wage distribution and marginal GPA
% distribution as input and decompose total uncertainty

rng(1)
TempR = randn(9,N);
TempT = G(:,1)*ones(1,N) + G(:,2)*TempR(1,:);

TempG = zeros(size(W,1),N);

for i = 1:8
    TempE = G(:,3)*TempR(i+1,:);
    Tempg = TempT + TempE;
    Tempg(Tempg < 0) = 0;
    Tempg(Tempg > 4) = 4;
    TempG = TempG + Tempg;
end

TempG = TempG/8;
W1 = repmat(W(:,1),[1,N]);
W2 = repmat(W(:,2),[1,N]);
W3 = repmat(W(:,3),[1,N]);
S1 = repmat(S(:,1),[1,N]);
S2 = repmat(S(:,2),[1,N]);
S3 = repmat(S(:,3),[1,N]);

w_Con = (TempG < 2).*W1 + (TempG < 3 & TempG >= 2).*(W1 + (TempG - 2)/1.*(W2 - W1)) + (TempG >= 3).*(W2 + (TempG - 3)/0.75.*(W3 - W2));
s_Con = (TempG < 2).*S1 + (TempG < 3 & TempG >= 2).*(S1 + (TempG - 2)/1.*(S2 - S1)) + (TempG >= 3).*(S2 + (TempG - 3)/0.75.*(S3 - S2));

M_Uncon = zeros(size(W,1),1);
V_Uncon_G = zeros(size(W,1),1);
V_Uncon_O = zeros(size(W,1),1);

for i = 1:size(W,1)
    w_Temp = w_Con(i,:);
    s_Temp = s_Con(i,:);
    
    M_Uncon(i) = mean(w_Temp(TempG(i,:) >= 2),2);
    V_Uncon_G(i) = var(w_Temp(TempG(i,:) >= 2),0,2);
    V_Uncon_O(i) = mean(s_Temp(TempG(i,:) >= 2).^2,2);
end

Ratio = V_Uncon_G./(V_Uncon_G + V_Uncon_O);



